==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QScrollEvent_shell.cpp <==
#include "QScrollEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QScrollEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScrollEvent")
    QScrollEvent *_ptr = reinterpret_cast<QScrollEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QScrollEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QScrollEvent_shell) ); }

jmethodID QScrollEvent_shell::__shell_javaMethod(int pos) const { return QScrollEvent_shell::__shell()->javaMethod(typeid(QScrollEvent), pos); }

// emitting (writeShellConstructor)
QScrollEvent_shell::QScrollEvent_shell(const QPointF& contentPos0, const QPointF& overshoot1, QScrollEvent::ScrollState scrollState2)
    : QScrollEvent(contentPos0, overshoot1, scrollState2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScrollEvent::QScrollEvent_shell(const QPointF& contentPos0, const QPointF& overshoot1, QScrollEvent::ScrollState scrollState2)", QScrollEvent_shell::__shell())
    QScrollEvent_shell::__shell()->constructed(typeid(QScrollEvent));
}

// emitting (writeShellDestructor)
QScrollEvent_shell::~QScrollEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QScrollEvent::~QScrollEvent()", QScrollEvent_shell::__shell())
    QScrollEvent_shell::__shell()->destructed(typeid(QScrollEvent));
}

void QScrollEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QScrollEvent_shell*>(ptr)->QScrollEvent_shell::__shell()->tryDeleteShell(typeid(QScrollEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
void __qt_construct_QScrollEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)")
    jobject contentPos0 = __java_arguments[0].l;
    const QPointF& __qt_contentPos0 = qtjambi_cast<const QPointF& >(__jni_env, contentPos0);
    jobject overshoot1 = __java_arguments[1].l;
    const QPointF& __qt_overshoot1 = qtjambi_cast<const QPointF& >(__jni_env, overshoot1);
    jobject scrollState2 = __java_arguments[2].l;
    QScrollEvent::ScrollState __qt_scrollState2 = qtjambi_cast<QScrollEvent::ScrollState>(__jni_env, scrollState2);
    QScrollEvent *__qt_this = new(__qtjambi_ptr) QScrollEvent_shell(__qt_contentPos0, __qt_overshoot1, QScrollEvent::ScrollState(__qt_scrollState2));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QScrollEvent_shell
void __qt_destruct_QScrollEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScrollEvent")
    reinterpret_cast<QScrollEvent_shell*>(ptr)->~QScrollEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScrollEvent::QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_initialize_1native__Lio_qt_gui_QScrollEvent_2Lio_qt_core_QPointF_2Lio_qt_core_QPointF_2Lio_qt_gui_QScrollEvent_00024ScrollState_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject contentPos0,
 jobject overshoot1,
 jobject scrollState2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScrollEvent::QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = contentPos0;
        arguments[1].l = overshoot1;
        arguments[2].l = scrollState2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScrollEvent_0, sizeof(QScrollEvent_shell), typeid(QScrollEvent), true, &deleter_QScrollEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollEvent::contentPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_contentPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollEvent::contentPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->contentPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollEvent::overshootDistance()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_overshootDistance_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollEvent::overshootDistance()const", __qt_this)
        QPointF __qt_return_value = __qt_this->overshootDistance();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollEvent::scrollState()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_scrollState_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollEvent::scrollState()const", __qt_this)
        QScrollEvent::ScrollState __qt_return_value = __qt_this->scrollState();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QScrollEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScrollEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QScrollEvent>("QScrollEvent", "io/qt/gui/QScrollEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScrollEvent, {
        ConstructorInfo(&__qt_construct_QScrollEvent_0, "Lio/qt/core/QPointF;Lio/qt/core/QPointF;Lio/qt/gui/QScrollEvent$ScrollState;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScrollEvent);
    registerSizeOfShell(typeId, sizeof(QScrollEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QScrollEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QScrollEvent::ScrollState>("QScrollEvent::ScrollState", "io/qt/gui/QScrollEvent$ScrollState");
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QScrollEvent_shell.cpp <==
#include "QScrollEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QScrollEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScrollEvent")
    QScrollEvent *_ptr = reinterpret_cast<QScrollEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QScrollEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QScrollEvent_shell) ); }

jmethodID QScrollEvent_shell::__shell_javaMethod(int pos) const { return QScrollEvent_shell::__shell()->javaMethod(typeid(QScrollEvent), pos); }

// emitting (writeShellConstructor)
QScrollEvent_shell::QScrollEvent_shell(const QPointF& contentPos0, const QPointF& overshoot1, QScrollEvent::ScrollState scrollState2)
    : QScrollEvent(contentPos0, overshoot1, scrollState2)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScrollEvent::QScrollEvent_shell(const QPointF& contentPos0, const QPointF& overshoot1, QScrollEvent::ScrollState scrollState2)", QScrollEvent_shell::__shell())
    QScrollEvent_shell::__shell()->constructed(typeid(QScrollEvent));
}

QScrollEvent_shell::QScrollEvent_shell(const QScrollEvent& other0)
    : QScrollEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScrollEvent::QScrollEvent_shell(const QScrollEvent& other0)", QScrollEvent_shell::__shell())
    QScrollEvent_shell::__shell()->constructed(typeid(QScrollEvent));
}

// emitting (writeShellDestructor)
QScrollEvent_shell::~QScrollEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QScrollEvent::~QScrollEvent()", QScrollEvent_shell::__shell())
    QScrollEvent_shell::__shell()->destructed(typeid(QScrollEvent));
}

void QScrollEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QScrollEvent_shell*>(ptr)->QScrollEvent_shell::__shell()->tryDeleteShell(typeid(QScrollEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
void __qt_construct_QScrollEvent_cref_QPointF_cref_QPointF_QScrollEvent_ScrollState(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)")
    jobject contentPos0 = __java_arguments[0].l;
    const QPointF& __qt_contentPos0 = qtjambi_cast<const QPointF& >(__jni_env, contentPos0);
    jobject overshoot1 = __java_arguments[1].l;
    const QPointF& __qt_overshoot1 = qtjambi_cast<const QPointF& >(__jni_env, overshoot1);
    jobject scrollState2 = __java_arguments[2].l;
    QScrollEvent::ScrollState __qt_scrollState2 = qtjambi_cast<QScrollEvent::ScrollState>(__jni_env, scrollState2);
    QScrollEvent *__qt_this = new(__qtjambi_ptr) QScrollEvent_shell(__qt_contentPos0, __qt_overshoot1, QScrollEvent::ScrollState(__qt_scrollState2));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScrollEvent::QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_initialize_1native__Lio_qt_gui_QScrollEvent_2Lio_qt_core_QPointF_2Lio_qt_core_QPointF_2Lio_qt_gui_QScrollEvent_00024ScrollState_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject contentPos0,
 jobject overshoot1,
 jobject scrollState2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScrollEvent::QScrollEvent(QPointF,QPointF,QScrollEvent::ScrollState)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = contentPos0;
        arguments[1].l = overshoot1;
        arguments[2].l = scrollState2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScrollEvent_cref_QPointF_cref_QPointF_QScrollEvent_ScrollState, sizeof(QScrollEvent_shell), typeid(QScrollEvent), true, &deleter_QScrollEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QScrollEvent(QScrollEvent)
void __qt_construct_QScrollEvent_cref_QScrollEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScrollEvent(QScrollEvent)")
    jobject other0 = __java_arguments[0].l;
    const QScrollEvent& __qt_other0 = qtjambi_cast<const QScrollEvent& >(__jni_env, other0);
    QScrollEvent *__qt_this = new(__qtjambi_ptr) QScrollEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScrollEvent::QScrollEvent(QScrollEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_initialize_1native__Lio_qt_gui_QScrollEvent_2Lio_qt_gui_QScrollEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScrollEvent::QScrollEvent(QScrollEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScrollEvent_cref_QScrollEvent, sizeof(QScrollEvent_shell), typeid(QScrollEvent), true, &deleter_QScrollEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScrollEvent_shell
void __qt_destruct_QScrollEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScrollEvent")
    reinterpret_cast<QScrollEvent_shell*>(ptr)->~QScrollEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScrollEvent::contentPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_contentPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollEvent::contentPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->contentPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollEvent::overshootDistance()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_overshootDistance_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollEvent::overshootDistance()const", __qt_this)
        QPointF __qt_return_value = __qt_this->overshootDistance();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollEvent::scrollState()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_scrollState_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollEvent::scrollState()const", __qt_this)
        QScrollEvent::ScrollState __qt_return_value = __qt_this->scrollState();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScrollEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QScrollEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScrollEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QScrollEvent>("QScrollEvent", "io/qt/gui/QScrollEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScrollEvent, {
        ConstructorInfo(&__qt_construct_QScrollEvent_cref_QPointF_cref_QPointF_QScrollEvent_ScrollState, "Lio/qt/core/QPointF;Lio/qt/core/QPointF;Lio/qt/gui/QScrollEvent$ScrollState;")
       ,ConstructorInfo(&__qt_construct_QScrollEvent_cref_QScrollEvent, "Lio/qt/gui/QScrollEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScrollEvent);
    registerSizeOfShell(typeId, sizeof(QScrollEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QScrollEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QScrollEvent::ScrollState>("QScrollEvent::ScrollState", "io/qt/gui/QScrollEvent$ScrollState");
// END: enums and flags
}
